@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminDynamicFieldText;
@@ -11,10 +11,10 @@ package Kernel::Modules::AdminDynamicFieldText;
 use strict;
 use warnings;
 
+our $ObjectManagerDisabled = 1;
+
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::System::Valid;
-use Kernel::System::CheckItem;
-use Kernel::System::DynamicField;
+use Kernel::Language qw(Translatable);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -22,29 +22,14 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    for (qw(ParamObject LayoutObject LogObject ConfigObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
-        }
-    }
-
-    # create additional objects
-    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
-
-    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new( %{$Self} );
-
-    # get configured object types
-    $Self->{ObjectTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::ObjectType');
-
-    # get the fields config
-    $Self->{FieldTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::Driver') || {};
-
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     if ( $Self->{Subaction} eq 'Add' ) {
         return $Self->_Add(
             %Param,
@@ -53,7 +38,7 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
         return $Self->_AddAction(
             %Param,
@@ -67,33 +52,37 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
         return $Self->_ChangeAction(
             %Param,
         );
     }
-    return $Self->{LayoutObject}->ErrorScreen(
-        Message => "Undefined subaction.",
+    return $LayoutObject->ErrorScreen(
+        Message => Translatable('Undefined subaction.'),
     );
 }
 
 sub _Add {
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     my %GetParam;
     for my $Needed (qw(ObjectType FieldType FieldOrder)) {
-        $GetParam{$Needed} = $Self->{ParamObject}->GetParam( Param => $Needed );
-        if ( !$GetParam{$Needed} ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => "Need $Needed",
+        $GetParam{$Needed} = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => $Needed );
+        if ( !$Needed ) {
+            return $LayoutObject->ErrorScreen(
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Need %s', $Needed ),
             );
         }
     }
 
     # get the object type and field type display name
-    my $ObjectTypeName = $Self->{ObjectTypeConfig}->{ $GetParam{ObjectType} }->{DisplayName} || '';
-    my $FieldTypeName  = $Self->{FieldTypeConfig}->{ $GetParam{FieldType} }->{DisplayName}   || '';
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $ObjectTypeName
+        = $ConfigObject->Get('DynamicFields::ObjectType')->{ $GetParam{ObjectType} }->{DisplayName} || '';
+    my $FieldTypeName = $ConfigObject->Get('DynamicFields::Driver')->{ $GetParam{FieldType} }->{DisplayName} || '';
 
     return $Self->_ShowScreen(
         %Param,
@@ -109,15 +98,18 @@ sub _AddAction {
 
     my %Errors;
     my %GetParam;
+    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     for my $Needed (qw(Name Label FieldOrder)) {
-        $GetParam{$Needed} = $Self->{ParamObject}->GetParam( Param => $Needed );
+        $GetParam{$Needed} = $ParamObject->GetParam( Param => $Needed );
         if ( !$GetParam{$Needed} ) {
             $Errors{ $Needed . 'ServerError' }        = 'ServerError';
-            $Errors{ $Needed . 'ServerErrorMessage' } = 'This field is required.';
+            $Errors{ $Needed . 'ServerErrorMessage' } = Translatable('This field is required.');
         }
     }
 
+    my $DynamicFieldObject = $Kernel::OM->Get('Kernel::System::DynamicField');
+
     if ( $GetParam{Name} ) {
 
         # check if name is alphanumeric
@@ -126,12 +118,12 @@ sub _AddAction {
             # add server error error class
             $Errors{NameServerError} = 'ServerError';
             $Errors{NameServerErrorMessage} =
-                'The field does not contain only ASCII letters and numbers.';
+                Translatable('The field does not contain only ASCII letters and numbers.');
         }
 
         # check if name is duplicated
         my %DynamicFieldsList = %{
-            $Self->{DynamicFieldObject}->DynamicFieldList(
+            $DynamicFieldObject->DynamicFieldList(
                 Valid      => 0,
                 ResultType => 'HASH',
                 )
@@ -143,7 +135,7 @@ sub _AddAction {
 
             # add server error error class
             $Errors{NameServerError}        = 'ServerError';
-            $Errors{NameServerErrorMessage} = 'There is another field with the same name.';
+            $Errors{NameServerErrorMessage} = Translatable('There is another field with the same name.');
         }
     }
 
@@ -154,28 +146,30 @@ sub _AddAction {
 
             # add server error error class
             $Errors{FieldOrderServerError}        = 'ServerError';
-            $Errors{FieldOrderServerErrorMessage} = 'The field must be numeric.';
+            $Errors{FieldOrderServerErrorMessage} = Translatable('The field must be numeric.');
         }
     }
 
     for my $ConfigParam (
-        qw(ObjectType ObjectTypeName FieldType FieldTypeName DefaultValue ValidID Rows Cols Link)
+        qw(ObjectType ObjectTypeName FieldType FieldTypeName DefaultValue ValidID Rows Cols Link LinkPreview)
         )
     {
-        $GetParam{$ConfigParam} = $Self->{ParamObject}->GetParam( Param => $ConfigParam );
+        $GetParam{$ConfigParam} = $ParamObject->GetParam( Param => $ConfigParam );
     }
 
-    $GetParam{RegExCounter} = $Self->{ParamObject}->GetParam( Param => 'RegExCounter' ) || 0;
+    $GetParam{RegExCounter} = $ParamObject->GetParam( Param => 'RegExCounter' ) || 0;
 
     my @RegExList = $Self->GetParamRegexList(
         GetParam => \%GetParam,
         Errors   => \%Errors,
     );
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     # uncorrectable errors
     if ( !$GetParam{ValidID} ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Need ValidID",
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('Need ValidID'),
         );
     }
 
@@ -196,7 +190,8 @@ sub _AddAction {
     };
 
     if ( $GetParam{FieldType} eq 'Text' ) {
-        $FieldConfig->{Link} = $GetParam{Link};
+        $FieldConfig->{Link}        = $GetParam{Link};
+        $FieldConfig->{LinkPreview} = $GetParam{LinkPreview};
     }
 
     if ( $GetParam{FieldType} eq 'TextArea' ) {
@@ -205,7 +200,7 @@ sub _AddAction {
     }
 
     # create a new field
-    my $FieldID = $Self->{DynamicFieldObject}->DynamicFieldAdd(
+    my $FieldID = $DynamicFieldObject->DynamicFieldAdd(
         Name       => $GetParam{Name},
         Label      => $GetParam{Label},
         FieldOrder => $GetParam{FieldOrder},
@@ -217,12 +212,12 @@ sub _AddAction {
     );
 
     if ( !$FieldID ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Could not create the new field",
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('Could not create the new field'),
         );
     }
 
-    return $Self->{LayoutObject}->Redirect(
+    return $LayoutObject->Redirect(
         OP => "Action=AdminDynamicField",
     );
 }
@@ -230,37 +225,43 @@ sub _AddAction {
 sub _Change {
     my ( $Self, %Param ) = @_;
 
+    my $ParamObject  = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
     my %GetParam;
+
     for my $Needed (qw(ObjectType FieldType)) {
-        $GetParam{$Needed} = $Self->{ParamObject}->GetParam( Param => $Needed );
-        if ( !$GetParam{$Needed} ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => "Need $Needed",
+        $GetParam{$Needed} = $ParamObject->GetParam( Param => $Needed );
+        if ( !$Needed ) {
+            return $LayoutObject->ErrorScreen(
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Need %s', $Needed ),
             );
         }
     }
 
     # get the object type and field type display name
-    my $ObjectTypeName = $Self->{ObjectTypeConfig}->{ $GetParam{ObjectType} }->{DisplayName} || '';
-    my $FieldTypeName  = $Self->{FieldTypeConfig}->{ $GetParam{FieldType} }->{DisplayName}   || '';
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $ObjectTypeName
+        = $ConfigObject->Get('DynamicFields::ObjectType')->{ $GetParam{ObjectType} }->{DisplayName} || '';
+    my $FieldTypeName = $ConfigObject->Get('DynamicFields::Driver')->{ $GetParam{FieldType} }->{DisplayName} || '';
 
-    my $FieldID = $Self->{ParamObject}->GetParam( Param => 'ID' );
+    my $FieldID = $ParamObject->GetParam( Param => 'ID' );
 
     if ( !$FieldID ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Need ID",
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('Need ID'),
         );
     }
 
     # get dynamic field data
-    my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
+    my $DynamicFieldData = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldGet(
         ID => $FieldID,
     );
 
     # check for valid dynamic field configuration
     if ( !IsHashRefWithData($DynamicFieldData) ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Could not get data for dynamic field $FieldID",
+        return $LayoutObject->ErrorScreen(
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for dynamic field %s', $FieldID ),
         );
     }
 
@@ -288,31 +289,36 @@ sub _ChangeAction {
 
     my %Errors;
     my %GetParam;
+    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     for my $Needed (qw(Name Label FieldOrder)) {
-        $GetParam{$Needed} = $Self->{ParamObject}->GetParam( Param => $Needed );
+        $GetParam{$Needed} = $ParamObject->GetParam( Param => $Needed );
         if ( !$GetParam{$Needed} ) {
             $Errors{ $Needed . 'ServerError' }        = 'ServerError';
-            $Errors{ $Needed . 'ServerErrorMessage' } = 'This field is required.';
+            $Errors{ $Needed . 'ServerErrorMessage' } = Translatable('This field is required.');
         }
     }
 
-    my $FieldID = $Self->{ParamObject}->GetParam( Param => 'ID' );
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $FieldID = $ParamObject->GetParam( Param => 'ID' );
     if ( !$FieldID ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Need ID",
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('Need ID'),
         );
     }
 
+    my $DynamicFieldObject = $Kernel::OM->Get('Kernel::System::DynamicField');
+
     # get dynamic field data
-    my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
+    my $DynamicFieldData = $DynamicFieldObject->DynamicFieldGet(
         ID => $FieldID,
     );
 
     # check for valid dynamic field configuration
     if ( !IsHashRefWithData($DynamicFieldData) ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Could not get data for dynamic field $FieldID",
+        return $LayoutObject->ErrorScreen(
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for dynamic field %s', $FieldID ),
         );
     }
 
@@ -324,12 +330,12 @@ sub _ChangeAction {
             # add server error error class
             $Errors{NameServerError} = 'ServerError';
             $Errors{NameServerErrorMessage} =
-                'The field does not contain only ASCII letters and numbers.';
+                Translatable('The field does not contain only ASCII letters and numbers.');
         }
 
         # check if name is duplicated
         my %DynamicFieldsList = %{
-            $Self->{DynamicFieldObject}->DynamicFieldList(
+            $DynamicFieldObject->DynamicFieldList(
                 Valid      => 0,
                 ResultType => 'HASH',
                 )
@@ -345,7 +351,7 @@ sub _ChangeAction {
 
             # add server error class
             $Errors{NameServerError}        = 'ServerError';
-            $Errors{NameServerErrorMessage} = 'There is another field with the same name.';
+            $Errors{NameServerErrorMessage} = Translatable('There is another field with the same name.');
         }
 
         # if it's an internal field, it's name should not change
@@ -357,7 +363,7 @@ sub _ChangeAction {
 
             # add server error class
             $Errors{NameServerError}        = 'ServerError';
-            $Errors{NameServerErrorMessage} = 'The name for this field should not change.';
+            $Errors{NameServerErrorMessage} = Translatable('The name for this field should not change.');
             $Param{InternalField}           = $DynamicFieldData->{InternalField};
         }
     }
@@ -369,18 +375,18 @@ sub _ChangeAction {
 
             # add server error error class
             $Errors{FieldOrderServerError}        = 'ServerError';
-            $Errors{FieldOrderServerErrorMessage} = 'The field must be numeric.';
+            $Errors{FieldOrderServerErrorMessage} = Translatable('The field must be numeric.');
         }
     }
 
     for my $ConfigParam (
-        qw(ObjectType ObjectTypeName FieldType FieldTypeName DefaultValue ValidID Rows Cols Link)
+        qw(ObjectType ObjectTypeName FieldType FieldTypeName DefaultValue ValidID Rows Cols Link LinkPreview)
         )
     {
-        $GetParam{$ConfigParam} = $Self->{ParamObject}->GetParam( Param => $ConfigParam );
+        $GetParam{$ConfigParam} = $ParamObject->GetParam( Param => $ConfigParam );
     }
 
-    $GetParam{RegExCounter} = $Self->{ParamObject}->GetParam( Param => 'RegExCounter' ) || 0;
+    $GetParam{RegExCounter} = $ParamObject->GetParam( Param => 'RegExCounter' ) || 0;
 
     my @RegExList = $Self->GetParamRegexList(
         GetParam => \%GetParam,
@@ -389,8 +395,8 @@ sub _ChangeAction {
 
     # uncorrectable errors
     if ( !$GetParam{ValidID} ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Need ValidID",
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('Need ValidID'),
         );
     }
 
@@ -403,7 +409,7 @@ sub _ChangeAction {
 
                 # add server error error class
                 $Errors{RowsServerError}        = 'ServerError';
-                $Errors{RowsServerErrorMessage} = 'The field must be numeric.';
+                $Errors{RowsServerErrorMessage} = Translatable('The field must be numeric.');
             }
         }
         if ( $GetParam{Cols} ) {
@@ -413,7 +419,7 @@ sub _ChangeAction {
 
                 # add server error error class
                 $Errors{ColsServerError}        = 'ServerError';
-                $Errors{ColsServerErrorMessage} = 'The field must be numeric.';
+                $Errors{ColsServerErrorMessage} = Translatable('The field must be numeric.');
             }
         }
     }
@@ -436,7 +442,8 @@ sub _ChangeAction {
     };
 
     if ( $GetParam{FieldType} eq 'Text' ) {
-        $FieldConfig->{Link} = $GetParam{Link};
+        $FieldConfig->{Link}        = $GetParam{Link};
+        $FieldConfig->{LinkPreview} = $GetParam{LinkPreview};
     }
 
     if ( $GetParam{FieldType} eq 'TextArea' ) {
@@ -445,7 +452,7 @@ sub _ChangeAction {
     }
 
     # update dynamic field (FieldType and ObjectType cannot be changed; use old values)
-    my $UpdateSuccess = $Self->{DynamicFieldObject}->DynamicFieldUpdate(
+    my $UpdateSuccess = $DynamicFieldObject->DynamicFieldUpdate(
         ID         => $FieldID,
         Name       => $GetParam{Name},
         Label      => $GetParam{Label},
@@ -458,12 +465,12 @@ sub _ChangeAction {
     );
 
     if ( !$UpdateSuccess ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Could not update the field $GetParam{Name}",
+        return $LayoutObject->ErrorScreen(
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Could not update the field %s', $GetParam{Name} ),
         );
     }
 
-    return $Self->{LayoutObject}->Redirect(
+    return $LayoutObject->Redirect(
         OP => "Action=AdminDynamicField",
     );
 }
@@ -478,12 +485,16 @@ sub _ShowScreen {
         $Param{DisplayFieldName} = $Param{Name};
     }
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     # header
-    my $Output = $Self->{LayoutObject}->Header();
-    $Output .= $Self->{LayoutObject}->NavigationBar();
+    my $Output = $LayoutObject->Header();
+    $Output .= $LayoutObject->NavigationBar();
+
+    my $DynamicFieldObject = $Kernel::OM->Get('Kernel::System::DynamicField');
 
     # get all fields
-    my $DynamicFieldList = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+    my $DynamicFieldList = $DynamicFieldObject->DynamicFieldListGet(
         Valid => 0,
     );
 
@@ -508,43 +519,43 @@ sub _ShowScreen {
 
     # show the names of the other fields to ease ordering
     my %OrderNamesList;
-    my $CurrentlyText = $Self->{LayoutObject}->{LanguageObject}->Translate('Currently') . ': ';
+    my $CurrentlyText = $LayoutObject->{LanguageObject}->Translate('Currently') . ': ';
     for my $OrderNumber ( sort @DynamicfieldOrderList ) {
         $OrderNamesList{$OrderNumber} = $OrderNumber;
         if ( $DynamicfieldNamesList{$OrderNumber} && $OrderNumber ne $Param{FieldOrder} ) {
             $OrderNamesList{$OrderNumber} = $OrderNumber . ' - '
                 . $CurrentlyText
-                . $DynamicfieldNamesList{$OrderNumber};
+                . $DynamicfieldNamesList{$OrderNumber}
         }
     }
 
-    my $DynamicFieldOrderStrg = $Self->{LayoutObject}->BuildSelection(
+    my $DynamicFieldOrderStrg = $LayoutObject->BuildSelection(
         Data          => \%OrderNamesList,
         Name          => 'FieldOrder',
         SelectedValue => $Param{FieldOrder} || 1,
         PossibleNone  => 0,
         Translation   => 0,
         Sort          => 'NumericKey',
-        Class         => 'W75pc Validate_Number',
+        Class         => 'Modernize W75pc Validate_Number',
     );
 
-    my %ValidList = $Self->{ValidObject}->ValidList();
+    my %ValidList = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
 
     # create the Validity select
-    my $ValidityStrg = $Self->{LayoutObject}->BuildSelection(
+    my $ValidityStrg = $LayoutObject->BuildSelection(
         Data         => \%ValidList,
         Name         => 'ValidID',
         SelectedID   => $Param{ValidID} || 1,
         PossibleNone => 0,
         Translation  => 1,
-        Class        => 'W50pc',
+        Class        => 'Modernize W50pc',
     );
 
     # define config field specific settings
     my $DefaultValue = ( defined $Param{DefaultValue} ? $Param{DefaultValue} : '' );
 
     # create the default value element
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'DefaultValue' . $Param{FieldType},
         Data => {
             %Param,
@@ -553,16 +564,18 @@ sub _ShowScreen {
     );
 
     # define config field specific settings
-    my $Link = $Param{Link} || '';
+    my $Link        = $Param{Link}        || '';
+    my $LinkPreview = $Param{LinkPreview} || '';
 
     if ( $Param{FieldType} eq 'Text' ) {
 
         # create the default link element
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'Link',
             Data => {
                 %Param,
-                Link => $Link,
+                Link        => $Link,
+                LinkPreview => $LinkPreview,
             },
         );
     }
@@ -570,7 +583,7 @@ sub _ShowScreen {
     if ( $Param{FieldType} eq 'TextArea' ) {
 
         # create the default value element
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ColsRowsValues',
             Data => {
                 %Param,
@@ -584,7 +597,7 @@ sub _ShowScreen {
 
     # Internal fields can not be deleted and name should not change.
     if ( $Param{InternalField} ) {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'InternalField',
             Data => {%Param},
         );
@@ -592,13 +605,13 @@ sub _ShowScreen {
     }
 
     # get the field id
-    my $FieldID = $Self->{ParamObject}->GetParam( Param => 'ID' );
+    my $FieldID = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => 'ID' );
 
     # only if the dymamic field exists and should be edited,
     # not if the field is added for the first time
     if ($FieldID) {
 
-        my $DynamicField = $Self->{DynamicFieldObject}->DynamicFieldGet(
+        my $DynamicField = $DynamicFieldObject->DynamicFieldGet(
             ID => $FieldID,
         );
 
@@ -625,7 +638,7 @@ sub _ShowScreen {
                 # check existing regex
                 next REGEXENTRY if !$Param{ 'RegEx_' . $CurrentRegExEntryID };
 
-                $Self->{LayoutObject}->Block(
+                $LayoutObject->Block(
                     Name => 'RegExRow',
                     Data => {
                         EntryCounter => $CurrentRegExEntryID,
@@ -658,7 +671,7 @@ sub _ShowScreen {
     }
 
     # generate output
-    $Output .= $Self->{LayoutObject}->Output(
+    $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminDynamicFieldText',
         Data         => {
             %Param,
@@ -668,10 +681,11 @@ sub _ShowScreen {
             DefaultValue          => $DefaultValue,
             ReadonlyInternalField => $ReadonlyInternalField,
             Link                  => $Link,
+            LinkPreview           => $LinkPreview,
             }
     );
 
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
 
     return $Output;
 }
@@ -686,24 +700,26 @@ sub GetParamRegexList {
     # Check regex list
     if ( $GetParam->{RegExCounter} && $GetParam->{RegExCounter} =~ m{\A\d+\z}xms ) {
 
+        my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
+
         REGEXENTRY:
         for my $CurrentRegExEntryID ( 1 .. $GetParam->{RegExCounter} ) {
 
             # check existing regex
             $GetParam->{ 'RegEx_' . $CurrentRegExEntryID }
-                = $Self->{ParamObject}->GetParam( Param => 'RegEx_' . $CurrentRegExEntryID );
+                = $ParamObject->GetParam( Param => 'RegEx_' . $CurrentRegExEntryID );
 
             next REGEXENTRY if !$GetParam->{ 'RegEx_' . $CurrentRegExEntryID };
 
             $GetParam->{ 'CustomerRegExErrorMessage_' . $CurrentRegExEntryID }
-                = $Self->{ParamObject}->GetParam( Param => 'CustomerRegExErrorMessage_' . $CurrentRegExEntryID );
+                = $ParamObject->GetParam( Param => 'CustomerRegExErrorMessage_' . $CurrentRegExEntryID );
 
             my $RegEx                     = $GetParam->{ 'RegEx_' . $CurrentRegExEntryID };
             my $CustomerRegExErrorMessage = $GetParam->{ 'CustomerRegExErrorMessage_' . $CurrentRegExEntryID };
 
             # is the regex valid?
             my $RegExCheck = eval {
-                qr{$RegEx}xms;
+                qr{$RegEx}xms
             };
 
             my $CurrentEntryErrors = 0;
@@ -728,7 +744,7 @@ sub GetParamRegexList {
                     'CustomerRegExErrorMessage_'
                         . $CurrentRegExEntryID
                         . 'ServerErrorMessage'
-                } = 'This field is required.';
+                } = Translatable('This field is required.');
 
                 $CurrentEntryErrors = 1;
             }
