@@ -1,6 +1,5 @@
 # --
-# Kernel/System/DB/mssql.pm - mssql database backend
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +11,13 @@ package Kernel::System::DB::mssql;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Time',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -60,7 +66,7 @@ sub LoadPreferences {
     #$Self->{'DB::ShellConnect'} = '';
 
     # init sql setting on db connect
-    if ( !$Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+    if ( !$Kernel::OM->Get('Kernel::Config')->Get('Database::ShellOutput') ) {
         $Self->{'DB::Connect'} = 'SET DATEFORMAT ymd';
     }
 
@@ -96,7 +102,7 @@ sub DatabaseCreate {
 
     # check needed stuff
     if ( !$Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Name!'
         );
@@ -112,7 +118,7 @@ sub DatabaseDrop {
 
     # check needed stuff
     if ( !$Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Name!'
         );
@@ -126,6 +132,9 @@ sub DatabaseDrop {
 sub TableCreate {
     my ( $Self, @Param ) = @_;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     my $SQLStart     = '';
     my $SQLEnd       = '';
     my $SQL          = '';
@@ -147,7 +156,7 @@ sub TableCreate {
             && $Tag->{TagType} eq 'Start'
             )
         {
-            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+            if ( $ConfigObject->Get('Database::ShellOutput') ) {
                 $SQLStart .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQLStart .= $Self->{'DB::Comment'} . " create table $Tag->{Name}\n";
@@ -304,10 +313,13 @@ sub TableCreate {
 sub TableDrop {
     my ( $Self, @Param ) = @_;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     my $SQL = '';
     for my $Tag (@Param) {
         if ( $Tag->{Tag} eq 'Table' && $Tag->{TagType} eq 'Start' ) {
-            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+            if ( $ConfigObject->Get('Database::ShellOutput') ) {
                 $SQL .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQL .= $Self->{'DB::Comment'} . " drop table $Tag->{Name}\n";
@@ -324,6 +336,9 @@ sub TableDrop {
 sub TableAlter {
     my ( $Self, @Param ) = @_;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     my $SQLStart      = '';
     my @SQL           = ();
     my @Index         = ();
@@ -334,7 +349,7 @@ sub TableAlter {
     my $Table         = '';
 
     my $Start = '';
-    if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+    if ( $ConfigObject->Get('Database::ShellOutput') ) {
         $Start = "GO\n";
     }
 
@@ -342,7 +357,7 @@ sub TableAlter {
 
         if ( $Tag->{Tag} eq 'TableAlter' && $Tag->{TagType} eq 'Start' ) {
             $Table = $Tag->{Name} || $Tag->{NameNew};
-            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+            if ( $ConfigObject->Get('Database::ShellOutput') ) {
                 $SQLStart .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQLStart .= $Self->{'DB::Comment'} . " alter table $Table\n";
@@ -563,7 +578,7 @@ sub IndexCreate {
     # check needed stuff
     for (qw(TableName Name Data)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -595,7 +610,7 @@ sub IndexDrop {
     # check needed stuff
     for (qw(TableName Name)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -612,7 +627,7 @@ sub ForeignKeyCreate {
     # check needed stuff
     for (qw(LocalTableName Local ForeignTableName Foreign)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -623,12 +638,12 @@ sub ForeignKeyCreate {
     # create foreign key name
     my $ForeignKey = "FK_$Param{LocalTableName}_$Param{Local}_$Param{Foreign}";
     if ( length($ForeignKey) > 60 ) {
-        my $MD5 = $Self->{MainObject}->MD5sum(
+        my $MD5 = $Kernel::OM->Get('Kernel::System::Main')->MD5sum(
             String => $ForeignKey,
         );
         $ForeignKey = substr $ForeignKey, 0, 58;
         $ForeignKey .= substr $MD5, 0,  1;
-        $ForeignKey .= substr $MD5, 61, 1;
+        $ForeignKey .= substr $MD5, 31, 1;
     }
 
     # add foreign key
@@ -644,7 +659,7 @@ sub ForeignKeyDrop {
     # check needed stuff
     for (qw(LocalTableName Local ForeignTableName Foreign)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -655,12 +670,12 @@ sub ForeignKeyDrop {
     # create foreign key name
     my $ForeignKey = "FK_$Param{LocalTableName}_$Param{Local}_$Param{Foreign}";
     if ( length($ForeignKey) > 60 ) {
-        my $MD5 = $Self->{MainObject}->MD5sum(
+        my $MD5 = $Kernel::OM->Get('Kernel::System::Main')->MD5sum(
             String => $ForeignKey,
         );
         $ForeignKey = substr $ForeignKey, 0, 58;
         $ForeignKey .= substr $MD5, 0,  1;
-        $ForeignKey .= substr $MD5, 61, 1;
+        $ForeignKey .= substr $MD5, 31, 1;
     }
 
     # drop foreign key
@@ -675,7 +690,7 @@ sub UniqueCreate {
     # check needed stuff
     for (qw(TableName Name Data)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -703,7 +718,7 @@ sub UniqueDrop {
     # check needed stuff
     for (qw(TableName Name)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -717,12 +732,17 @@ sub UniqueDrop {
 sub Insert {
     my ( $Self, @Param ) = @_;
 
+    # get needed objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $TimeObject   = $Kernel::OM->Get('Kernel::System::Time');
+
     my $SQL    = '';
     my @Keys   = ();
     my @Values = ();
+    TAG:
     for my $Tag (@Param) {
         if ( $Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'Start' ) {
-            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+            if ( $ConfigObject->Get('Database::ShellOutput') ) {
                 $SQL .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQL .= $Self->{'DB::Comment'} . " insert into table $Tag->{Table}\n";
@@ -735,14 +755,14 @@ sub Insert {
 
             # do not use auto increment values
             if ( $Tag->{Type} && $Tag->{Type} =~ /^AutoIncrement$/i ) {
-                next;
+                next TAG;
             }
             $Tag->{Key} = ${ $Self->Quote( \$Tag->{Key} ) };
             push @Keys, $Tag->{Key};
             my $Value;
             if ( defined $Tag->{Value} ) {
                 $Value = $Tag->{Value};
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message  => 'The content for inserts is not longer appreciated '
                         . 'attribut Value, use Content from now on! Reason: You can\'t '
@@ -777,11 +797,11 @@ sub Insert {
             $Value .= ', ';
         }
         if ( $Tmp eq 'current_timestamp' ) {
-            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+            if ( $ConfigObject->Get('Database::ShellOutput') ) {
                 $Value .= $Tmp;
             }
             else {
-                my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
+                my $Timestamp = $TimeObject->CurrentTimestamp();
                 $Value .= '\'' . $Timestamp . '\'';
             }
         }
