@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::LinkObject::Ticket;
@@ -11,8 +11,6 @@ package Kernel::System::LinkObject::Ticket;
 use strict;
 use warnings;
 
-use Kernel::System::VariableCheck qw(:all);
-
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Log',
@@ -282,20 +280,8 @@ sub ObjectSearch {
             ContentSearch => 'OR',
         );
     }
-    if ( $Param{SearchParams}->{Title} ) {
-        $Search{Title} = '*' . $Param{SearchParams}->{Title} . '*';
-    }
-
-    if ( IsArrayRefWithData( $Param{SearchParams}->{ArchiveID} ) ) {
-        if ( $Param{SearchParams}->{ArchiveID}->[0] eq 'AllTickets' ) {
-            $Search{ArchiveFlags} = [ 'y', 'n' ];
-        }
-        elsif ( $Param{SearchParams}->{ArchiveID}->[0] eq 'NotArchivedTickets' ) {
-            $Search{ArchiveFlags} = ['n'];
-        }
-        elsif ( $Param{SearchParams}->{ArchiveID}->[0] eq 'ArchivedTickets' ) {
-            $Search{ArchiveFlags} = ['y'];
-        }
+    if ( $Param{SearchParams}->{TicketTitle} ) {
+        $Search{Title} = '*' . $Param{SearchParams}->{TicketTitle} . '*';
     }
 
     # get ticket object
@@ -640,10 +626,10 @@ sub LinkDeletePost {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
