@@ -1,5 +1,4 @@
 # --
-# Kernel/System/MailAccount/IMAP.pm - lib for imap accounts
 # Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -190,14 +189,6 @@ sub _Fetch {
             }
             else {
 
-                # safety protection
-                $FetchCounter++;
-                my $FetchDelay = ( $FetchCounter % 20 == 0 ? 1 : 0 );
-                if ( $FetchDelay && $CMD ) {
-                    print "$AuthType: Safety protection: waiting 1 second before processing next mail...\n";
-                    sleep 1;
-                }
-
                 # get message (header and body)
                 my @Lines = $IMAPObject->get($Messageno);
 
