@@ -160,7 +160,12 @@ sub _execute_command {    ## no critic
         }
     );
 
-    $Self->{UnitTestObject}->True( 1, $TestName );
+    if ( $Self->{SuppressCommandRecording} ) {
+        print $TestName;
+    }
+    else {
+        $Self->{UnitTestObject}->True( 1, $TestName );
+    }
 
     return $Result;
 }
@@ -308,6 +313,8 @@ sub WaitFor {
         die "Need JavaScript.";
     }
 
+    local $Self->{SuppressCommandRecording} = 1;
+
     $Param{Time} //= 20;
     my $WaitedSeconds = 0;
     my $Interval      = 0.1;
