@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -11,36 +11,47 @@
 var Core = Core || {};
 
 /**
- * @namespace
- * @exports TargetNS as Core.Agent
+ * @namespace Core
+ * @author OTRS AG
+ */
+
+/**
+ * @namespace Core.Agent
+ * @memberof Core
+ * @author OTRS AG
  * @description
  *      This namespace contains the config options and functions.
  */
 Core.Agent = (function (TargetNS) {
     if (!Core.Debug.CheckDependency('Core.Agent', 'Core.UI', 'Core.UI')) {
-        return;
+        return false;
     }
     if (!Core.Debug.CheckDependency('Core.Agent', 'Core.Form', 'Core.Form')) {
-        return;
+        return false;
     }
     if (!Core.Debug.CheckDependency('Core.Agent', 'Core.Form.Validate', 'Core.Form.Validate')) {
-        return;
+        return false;
     }
     if (!Core.Debug.CheckDependency('Core.Agent', 'Core.UI.Accessibility', 'Core.UI.Accessibility')) {
-        return;
+        return false;
+    }
+    if (!Core.Debug.CheckDependency('Core.Agent', 'Core.UI.InputFields', 'Core.UI.InputFields')) {
+        return false;
     }
     if (!Core.Debug.CheckDependency('Core.Agent', 'Core.UI.TreeSelection', 'Core.UI.TreeSelection')) {
-        return;
+        return false;
     }
     if (!Core.Debug.CheckDependency('Core.Agent', 'Core.AJAX', 'Core.AJAX')) {
-        return;
+        return false;
     }
 
     /**
-     * @function
      * @private
-     * @return nothing
-     *      This function initializes the main navigation
+     * @name InitNavigation
+     * @memberof Core.Agent
+     * @function
+     * @description
+     *      This function initializes the main navigation.
      */
     function InitNavigation() {
         /*
@@ -54,20 +65,27 @@ Core.Agent = (function (TargetNS) {
             NavigationResizeTimeout;
 
         /**
-         * @function
          * @private
-         * @return nothing
-         *      This function sets the Timeout for closing a subnav
+         * @name CreateSubnavCloseTimeout
+         * @memberof Core.Agent.InitNavigation
+         * @function
+         * @param {jQueryObject} $Element
+         * @param {Function} TimeoutFunction
+         * @description
+         *      This function sets the Timeout for closing a subnav.
          */
         function CreateSubnavCloseTimeout($Element, TimeoutFunction) {
             NavigationTimer[$Element.attr('id')] = setTimeout(TimeoutFunction, NavigationDuration);
         }
 
         /**
-         * @function
          * @private
-         * @return nothing
-         *      This function clears the Timeout for a subnav
+         * @name ClearSubnavCloseTimeout
+         * @memberof Core.Agent.InitNavigation
+         * @function
+         * @param {jQueryObject} $Element
+         * @description
+         *      This function clears the Timeout for a subnav.
          */
         function ClearSubnavCloseTimeout($Element) {
             if (typeof NavigationTimer[$Element.attr('id')] !== 'undefined') {
@@ -76,20 +94,27 @@ Core.Agent = (function (TargetNS) {
         }
 
         /**
-         * @function
          * @private
-         * @return nothing
-         *      This function sets the Timeout for closing a subnav
+         * @name CreateSubnavOpenTimeout
+         * @memberof Core.Agent.InitNavigation
+         * @function
+         * @param {jQueryObject} $Element
+         * @param {Function} TimeoutFunction
+         * @description
+         *      This function sets the Timeout for closing a subnav.
          */
         function CreateSubnavOpenTimeout($Element, TimeoutFunction) {
             NavigationHoverTimer[$Element.attr('id')] = setTimeout(TimeoutFunction, NavigationHoverDuration);
         }
 
         /**
-         * @function
          * @private
-         * @return nothing
-         *      This function clears the Timeout for a subnav
+         * @name ClearSubnavOpenTimeout
+         * @memberof Core.Agent.InitNavigation
+         * @function
+         * @param {jQueryObject} $Element
+         * @description
+         *      This function clears the Timeout for a subnav.
          */
         function ClearSubnavOpenTimeout($Element) {
             if (typeof NavigationHoverTimer[$Element.attr('id')] !== 'undefined') {
@@ -97,6 +122,22 @@ Core.Agent = (function (TargetNS) {
             }
         }
 
+        /**
+         * @private
+         * @name SetNavContainerHeight
+         * @memberof Core.Agent.InitNavigation
+         * @function
+         * @param {jQueryObject} $ParentElement
+         * @description
+         *      This function sets the nav container height according to the required height of the currently expanded sub menu
+         *      Due to the needed overflow: hidden property of the container, they would be hidden otherwise
+         */
+        function SetNavContainerHeight($ParentElement) {
+            if ($ParentElement.find('ul').length) {
+                $('#NavigationContainer').css('height', parseInt(InitialNavigationContainerHeight, 10) + parseInt($ParentElement.find('ul').outerHeight(), 10));
+            }
+        }
+
         $('#Navigation > li')
             .addClass('CanDrag')
             .filter(function () {
@@ -112,17 +153,15 @@ Core.Agent = (function (TargetNS) {
 
                 // special treatment for the first menu level: by default this opens submenus only via click,
                 //  but the config setting "OpenMainMenuOnHover" also activates opening on hover for it.
-                if ($Element.parent().attr('id') !== 'Navigation' || Core.Config.Get('OpenMainMenuOnHover')) {
+                if ($('body').hasClass('Visible-ScreenXL') && !Core.App.Responsive.IsTouchDevice() && ($Element.parent().attr('id') !== 'Navigation' || Core.Config.Get('OpenMainMenuOnHover'))) {
 
                     // Set Timeout for opening nav
                     CreateSubnavOpenTimeout($Element, function () {
                         $Element.addClass('Active').attr('aria-expanded', true)
                             .siblings().removeClass('Active');
 
-                        // Resize the container in order to display subitems
-                        // Due to the needed overflow: hidden property of the
-                        // container, they would be hidden otherwise
-                        $('#NavigationContainer').css('height', '500px');
+                        // resize the nav container
+                        SetNavContainerHeight($Element);
 
                         // If Timeout is set for this nav element, clear it
                         ClearSubnavCloseTimeout($Element);
@@ -133,50 +172,84 @@ Core.Agent = (function (TargetNS) {
 
                 var $Element = $(this);
 
-                // Clear Timeout for opening items on hover. Submenus should only be opened intentional,
-                // so if the user doesn't hover long enough, he probably doesn't want the submenu to be opened.
-                // If Timeout is set for this nav element, clear it
-                ClearSubnavOpenTimeout($Element);
+                if ($('body').hasClass('Visible-ScreenXL')) {
 
-                if (!$Element.hasClass('Active')) {
-                    return;
-                }
+                    // Clear Timeout for opening items on hover. Submenus should only be opened intentional,
+                    // so if the user doesn't hover long enough, he probably doesn't want the submenu to be opened.
+                    // If Timeout is set for this nav element, clear it
+                    ClearSubnavOpenTimeout($Element);
 
-                // Set Timeout for closing nav
-                CreateSubnavCloseTimeout($Element, function () {
-                    $Element.removeClass('Active').attr('aria-expanded', false);
-                    if (!$('#Navigation > li.Active').length) {
-                        $('#NavigationContainer').css('height', InitialNavigationContainerHeight);
+                    if (!$Element.hasClass('Active')) {
+                        return false;
                     }
-                });
+
+                    // Set Timeout for closing nav
+                    CreateSubnavCloseTimeout($Element, function () {
+                        $Element.removeClass('Active').attr('aria-expanded', false);
+                        if (!$('#Navigation > li.Active').length) {
+                            $('#NavigationContainer').css('height', InitialNavigationContainerHeight);
+                        }
+                    });
+                }
             })
             .bind('click', function (Event) {
 
+                var $Element = $(this),
+                    $Target = $(Event.target);
+
+                // if an onclick attribute is present, the attribute should win
+                if ($Target.attr('onclick')) {
+                    return false;
+                }
+
                 // if OpenMainMenuOnHover is enabled, clicking the item
                 // should lead to the link as regular
-                if (Core.Config.Get('OpenMainMenuOnHover')) {
+                if ($('body').hasClass('Visible-ScreenXL') && !Core.App.Responsive.IsTouchDevice() && Core.Config.Get('OpenMainMenuOnHover')) {
+                    return true;
+                }
+
+                if (!Core.Config.Get('OTRSBusinessIsInstalled') && $Target.hasClass('OTRSBusinessRequired')) {
+                    return true;
+                }
+
+                // Workaround for Windows Phone IE
+                // In Windows Phone IE the event does not bubble up like in other browsers
+                // That means that a subnavigation in mobile mode is still collapsed/expanded,
+                // although the link to the new page is clicked
+                // we force the redirect with this workaround
+                if ($Target.closest('ul').attr('id') !== 'Navigation') {
+                    window.location.href = $Target.closest('a').attr('href');
+                    Event.stopPropagation();
+                    Event.preventDefault();
                     return true;
                 }
 
-                var $Element = $(this),
-                    $Target = $(Event.target);
                 if ($Element.hasClass('Active')) {
                     $Element.removeClass('Active').attr('aria-expanded', false);
 
-                    // restore initial container height
-                    $('#NavigationContainer').css('height', InitialNavigationContainerHeight);
+                    if ($('body').hasClass('Visible-ScreenXL')) {
+                        // restore initial container height
+                        $('#NavigationContainer').css('height', InitialNavigationContainerHeight);
+                    }
                 }
                 else {
                     $Element.addClass('Active').attr('aria-expanded', true)
                         .siblings().removeClass('Active');
-                    $('#NavigationContainer').css('height', '300px');
 
-                    // If Timeout is set for this nav element, clear it
-                    ClearSubnavCloseTimeout($Element);
+                    if ($('body').hasClass('Visible-ScreenXL')) {
+
+                        // resize the nav container
+                        SetNavContainerHeight($Element);
+
+                        // If Timeout is set for this nav element, clear it
+                        ClearSubnavCloseTimeout($Element);
+                    }
                 }
+
                 // If element has subnavigation, prevent the link
                 if ($Target.closest('li').find('ul').length) {
                     Event.preventDefault();
+                    Event.stopPropagation();
                     return false;
                 }
             })
@@ -196,37 +269,49 @@ Core.Agent = (function (TargetNS) {
 
         // make the navigation items sortable (if enabled)
         if (Core.Config.Get('MenuDragDropEnabled') === 1) {
-            Core.UI.DnD.Sortable(
-                $('#Navigation'),
-                {
-                    Items: 'li.CanDrag',
-                    Tolerance: 'pointer',
-                    Distance: 15,
-                    Opacity: 0.6,
-                    Helper: 'clone',
-                    Axis: 'x',
-                    Containment: $('#Navigation'),
-                    Update: function (event, ui) {
+            Core.App.Subscribe('Event.App.Responsive.ScreenXL', function () {
+                $('#NavigationContainer').css('height', '35px');
+                Core.UI.DnD.Sortable(
+                    $('#Navigation'),
+                    {
+                        Items: 'li.CanDrag',
+                        Tolerance: 'pointer',
+                        Distance: 15,
+                        Opacity: 0.6,
+                        Helper: 'clone',
+                        Axis: 'x',
+                        Containment: $('#Navigation'),
+                        Update: function () {
 
-                        // collect navigation bar items
-                        var Items = [];
-                        $.each($('#Navigation').children('li'), function() {
-                            Items.push($(this).attr('id'));
-                        });
+                            // collect navigation bar items
+                            var Items = [];
+                            $.each($('#Navigation').children('li'), function() {
+                                Items.push($(this).attr('id'));
+                            });
 
-                        // save the new order to the users preferences
-                        TargetNS.PreferencesUpdate('UserNavBarItemsOrder', Core.JSON.Stringify(Items));
+                            // save the new order to the users preferences
+                            TargetNS.PreferencesUpdate('UserNavBarItemsOrder', Core.JSON.Stringify(Items));
 
-                        $('#Navigation').after('<i class="fa fa-check"></i>').next('.fa-check').css('left', $('#Navigation').outerWidth() + 10).delay(200).fadeIn(function() {
-                            $(this).delay(1500).fadeOut();
-                        });
+                            $('#Navigation').after('<i class="fa fa-check"></i>').next('.fa-check').css('left', $('#Navigation').outerWidth() + 10).delay(200).fadeIn(function() {
+                                $(this).delay(1500).fadeOut();
+                            });
 
-                        // make sure to re-size the nav container to its initial height after
-                        // dragging is finished in case a sub menu was open when the user started dragging.
-                        $('#NavigationContainer').css('height', InitialNavigationContainerHeight);
+                            // make sure to re-size the nav container to its initial height after
+                            // dragging is finished in case a sub menu was open when the user started dragging.
+                            // remember to remove this setting on smaller screens (see SmallerOrEqualScreenL below)
+                            $('#NavigationContainer').css('height', InitialNavigationContainerHeight);
+                        }
                     }
+                );
+            });
+
+            // disable sortable on smaller screens
+            Core.App.Subscribe('Event.App.Responsive.SmallerOrEqualScreenL', function () {
+                if ($('#Navigation').sortable("instance")) {
+                    $('#Navigation').sortable("destroy");
+                    $('#NavigationContainer').css('height', '100%');
                 }
-            );
+            });
         }
 
         /*
@@ -242,13 +327,29 @@ Core.Agent = (function (TargetNS) {
          * Register event for global search
          *
          */
-        $('#GlobalSearchNav').bind('click', function (Event) {
-            Core.Agent.Search.OpenSearchDialog();
+        $('#GlobalSearchNav, #GlobalSearchNavResponsive').bind('click', function () {
+            var SearchFrontend = Core.Config.Get('SearchFrontend');
+            if (SearchFrontend) {
+                try {
+                    eval(SearchFrontend); //eslint-disable-line no-eval
+                }
+                catch(Error) {
+                    $.noop(Error);
+                }
+            }
+            else {
+                Core.Agent.Search.OpenSearchDialog();
+            }
             return false;
         });
 
         TargetNS.ResizeNavigationBar();
         $(window).resize(function() {
+            // navigation resizing only possible in ScreenXL mode
+            if (!$('body').hasClass('Visible-ScreenXL')) {
+                return;
+            }
+
             window.clearTimeout(NavigationResizeTimeout);
             NavigationResizeTimeout = window.setTimeout(function () {
                 TargetNS.ResizeNavigationBar(true);
@@ -256,6 +357,17 @@ Core.Agent = (function (TargetNS) {
         });
     }
 
+
+    /**
+     * @private
+     * @name NavigationBarShowSlideButton
+     * @memberof Core.Agent
+     * @function
+     * @param {String} Direction Right | Left
+     * @param {Number} Difference
+     * @description
+     *      Show slide button, if navigation is wider than the screen.
+     */
     function NavigationBarShowSlideButton(Direction, Difference) {
 
         var Opposites = (Direction === 'Right') ? 'Left' : 'Right',
@@ -326,16 +438,16 @@ Core.Agent = (function (TargetNS) {
     }
 
     /**
+     * @name ReorderNavigationItems
+     * @memberof Core.Agent
      * @function
-     * @private
-     * @return nothing
-     *      This function re-orders the navigation items based on the users preferences
+     * @param {Array} NavbarCustomOrderItems
+     * @description
+     *      This function re-orders the navigation items based on the users preferences.
      */
     TargetNS.ReorderNavigationItems = function(NavbarCustomOrderItems) {
 
-        var CurrentItems,
-            IDA,
-            IDB;
+        var CurrentItems;
 
         if (NavbarCustomOrderItems && Core.Config.Get('MenuDragDropEnabled') === 1) {
 
@@ -368,6 +480,15 @@ Core.Agent = (function (TargetNS) {
         $('#Navigation').hide().css('visibility', 'visible').show();
     };
 
+    /**
+     * @private
+     * @name ToolBarIsAside
+     * @memberof Core.Agent
+     * @function
+     * @returns {Boolean} true, if toolbar is next to navigation bar, false otherwise.
+     * @description
+     *      Checks if the toolbar is next to the navigation bar.
+     */
     function ToolBarIsAside() {
 
         // the following needs to be the case if the Toolbar is next to the
@@ -377,20 +498,23 @@ Core.Agent = (function (TargetNS) {
         // (2) 'top' of #NavigationContainer is smaller than the height of the #ToolBar
         //      which would typically mean there is not enough space on top of #NavigationContainer
         //      to display the ToolBar.
-        if ( ( !$('body').hasClass('RTL') &&
-            ( parseInt($('#ToolBar').css('left'), 10) > parseInt($('#ToolBar').css('right'), 10) || isNaN(parseInt($('#ToolBar').css('left'), 10)) ) &&
-            parseInt($('#NavigationContainer').css('top'), 10) < parseInt($('#ToolBar').height(), 10) ) ||
+        if ((!$('body').hasClass('RTL') &&
+            (parseInt($('#ToolBar').css('left'), 10) > parseInt($('#ToolBar').css('right'), 10) || isNaN(parseInt($('#ToolBar').css('left'), 10))) &&
+            parseInt($('#NavigationContainer').css('top'), 10) < parseInt($('#ToolBar').height(), 10)) ||
             ($('body').hasClass('RTL') &&
-            ( parseInt($('#ToolBar').css('left'), 10) < parseInt($('#ToolBar').css('right'), 10) || isNaN(parseInt($('#ToolBar').css('right'), 10)) ) &&
-            parseInt($('#NavigationContainer').css('top'), 10) < parseInt($('#ToolBar').height(), 10) ) ) {
+            (parseInt($('#ToolBar').css('left'), 10) < parseInt($('#ToolBar').css('right'), 10) || isNaN(parseInt($('#ToolBar').css('right'), 10))) &&
+            parseInt($('#NavigationContainer').css('top'), 10) < parseInt($('#ToolBar').height(), 10))) {
             return true;
         }
         return false;
     }
 
     /**
+     * @name ResizeNavigationBar
+     * @memberof Core.Agent
      * @function
-     * @return nothing
+     * @param {Boolean} RealResizeEvent
+     * @description
      *      This function checks if the navigation bar needs to be resized and equipped
      *      with slider navigation buttons. This can only happen if there are too many
      *      navigation icons.
@@ -398,9 +522,13 @@ Core.Agent = (function (TargetNS) {
     TargetNS.ResizeNavigationBar = function (RealResizeEvent) {
 
         var NavigationBarWidth = 0,
-            Difference,
             NewContainerWidth;
 
+        // navigation resizing only possible in ScreenXL mode
+        if (RealResizeEvent && !$('body').hasClass('Visible-ScreenXL')) {
+            return;
+        }
+
         // set the original width (from css) of #NavigationContainer to have it available later
         if (!$('#NavigationContainer').attr('data-original-width')) {
             $('#NavigationContainer').attr('data-original-width', parseInt(parseInt($('#NavigationContainer').css('width'), 10) / $('body').width() * 100, 10) + '%');
@@ -412,7 +540,7 @@ Core.Agent = (function (TargetNS) {
         $('.NavigationBarNavigateLeft').remove();
 
         // when we have the toolbar being displayed next to the navigation, we need to leave some space for it
-        if ( ToolBarIsAside() && ( !$('#NavigationContainer').hasClass('IsResized') || RealResizeEvent ) ) {
+        if (ToolBarIsAside() && (!$('#NavigationContainer').hasClass('IsResized') || RealResizeEvent)) {
 
             // reset back to original width to avoid making it smaller and smaller
             $('#NavigationContainer').css('width', $('#NavigationContainer').attr('data-original-width'));
@@ -429,7 +557,7 @@ Core.Agent = (function (TargetNS) {
         $('#Navigation > li').each(function() {
             NavigationBarWidth += parseInt($(this).outerWidth(true), 10);
         });
-        $('#Navigation').css('width', (NavigationBarWidth + 2) + 'px');
+        $('#Navigation').css('width', (NavigationBarWidth + 3) + 'px');
 
         if (NavigationBarWidth > $('#NavigationContainer').outerWidth()) {
             NavigationBarShowSlideButton('Right', parseInt($('#NavigationContainer').outerWidth(true) - NavigationBarWidth, 10));
@@ -452,13 +580,30 @@ Core.Agent = (function (TargetNS) {
         }
     };
 
+    /**
+     * @name SupportedBrowser
+     * @memberof Core.Agent
+     * @member {Boolean}
+     * @description
+     *     Indicates a supported browser.
+     */
     TargetNS.SupportedBrowser = true;
+
+    /**
+     * @name IECompatibilityMode
+     * @memberof Core.Agent
+     * @member {Boolean}
+     * @description
+     *     IE Compatibility Mode is active.
+     */
     TargetNS.IECompatibilityMode = false;
 
     /**
+     * @name Init
+     * @memberof Core.Agent
      * @function
-     * @return nothing
-     *      This function initializes the application and executes the needed functions
+     * @description
+     *      This function initializes the application and executes the needed functions.
      */
     TargetNS.Init = function () {
         TargetNS.SupportedBrowser = Core.App.BrowserCheck('Agent');
@@ -470,16 +615,18 @@ Core.Agent = (function (TargetNS) {
         }
 
         if (!TargetNS.SupportedBrowser) {
-            alert( Core.Config.Get('BrowserTooOldMsg') + ' ' + Core.Config.Get('BrowserListMsg') + ' ' + Core.Config.Get('BrowserDocumentationMsg') );
+            alert(Core.Config.Get('BrowserTooOldMsg') + ' ' + Core.Config.Get('BrowserListMsg') + ' ' + Core.Config.Get('BrowserDocumentationMsg'));
         }
 
+        Core.App.Responsive.CheckIfTouchDevice();
+
         InitNavigation();
         Core.Exception.Init();
-        Core.UI.Table.InitCSSPseudoClasses();
         Core.UI.InitWidgetActionToggle();
         Core.UI.InitMessageBoxClose();
         Core.Form.Validate.Init();
         Core.UI.Popup.Init();
+        Core.UI.InputFields.Init();
         Core.UI.TreeSelection.InitTreeSelection();
         Core.UI.TreeSelection.InitDynamicFieldTreeViewRestore();
         // late execution of accessibility code
@@ -487,12 +634,14 @@ Core.Agent = (function (TargetNS) {
     };
 
     /**
+     * @name PreferencesUpdate
+     * @memberof Core.Agent
      * @function
+     * @returns {Boolean} returns true.
+     * @param {jQueryObject} Key - The name of the setting.
+     * @param {jQueryObject} Value - The value of the setting.
      * @description
-     *      This function set and session and preferences setting at runtime
-     * @param {jQueryObject} Key the name of the setting
-     * @param {jQueryObject} Value the value of the setting
-     * @return nothing
+     *      This function sets session and preferences setting at runtime.
      */
     TargetNS.PreferencesUpdate = function (Key, Value) {
         var URL = Core.Config.Get('Baselink'),
@@ -508,8 +657,10 @@ Core.Agent = (function (TargetNS) {
     };
 
     /**
+     * @name CheckSessionExpiredAndReload
+     * @memberof Core.Agent
      * @function
-     * @return nothing
+     * @description
      *      This function reload the page if the session is over and a login form is showed in some part of the current screen.
      */
     TargetNS.CheckSessionExpiredAndReload = function () {
